@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,8 +23,7 @@
 #include <QWebEngineView>
 #include <QWebEngineScript>
 #include "webengineviewer_export.h"
-namespace WebEngineViewer
-{
+namespace WebEngineViewer {
 class WebEngineViewPrivate;
 class WebEngineManageScript;
 class LocalDataBaseManager;
@@ -34,19 +33,19 @@ class WEBENGINEVIEWER_EXPORT WebEngineView : public QWebEngineView
     Q_OBJECT
 public:
     explicit WebEngineView(QWidget *parent = nullptr);
-    ~WebEngineView();
+    ~WebEngineView() override;
 
     void clearRelativePosition();
     void saveRelativePosition();
-    qreal relativePosition() const;
+    Q_REQUIRED_RESULT qreal relativePosition() const;
 
     void addScript(const QString &source, const QString &scriptName, QWebEngineScript::InjectionPoint injectionPoint);
     void initializeJQueryScript();
 
-    WebEngineManageScript *webEngineManagerScript() const;
+    Q_REQUIRED_RESULT WebEngineManageScript *webEngineManagerScript() const;
     void setLinkHovered(const QUrl &url);
 
-    WebEngineViewer::LocalDataBaseManager *phishingDatabase() const;
+    Q_REQUIRED_RESULT WebEngineViewer::LocalDataBaseManager *phishingDatabase() const;
 
 protected:
     bool eventFilter(QObject *obj, QEvent *event) override;
